netapp_ontap.models.application_statistics_space API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_statistics_space`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationStatisticsSpaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationStatisticsSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `available GET`

    The available amount of space left in the application component. Note that this field has limited meaning for SAN applications. Space may be considered used from ONTAP's perspective while the host filesystem still considers it available.

  `logical_used GET`

    The amount of space that would currently be used if no space saving features were enabled. For example, if compression were the only space saving feature enabled, this field would represent the uncompressed amount of space used.

  `provisioned GET`

    The originally requested amount of space that was provisioned for the application component.

  `reserved_unused GET`

    The amount of space reserved for system features such as Snapshot copies that has not yet been used.

  `savings GET`

    The amount of space saved by all enabled space saving features.

  `used GET`

    The amount of space that is currently being used by the application component. Note that this includes any space reserved by the system for features such as Snapshot copies.

  `used_excluding_reserves GET`

    The amount of space that is currently being used, excluding any space that is reserved by the system for features such as Snapshot copies.

  `used_percent GET`

    The percentage of the originally provisioned space that is currently being used by the application component.